==> custom_pages-v1.12.9.zip: custom_pages/messages/sk/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Pridať</strong> položku {templateName}',
    '<strong>Custom</strong> Pages' => '<strong>Vlastné</strong> Stránky',
    '<strong>Edit</strong> snippet' => '<strong>Zmeniť</strong> snippet',
    'Add' => 'Pridať',
    'Add a file icon before the title' => 'Pridajte ikonu súboru pred názov',
    'Additional IFrame Attributes' => 'Ďalšie atribúty IFrame',
    'Adds plain HTML content to your site.' => 'Pridať na vašu stránku obyčajný HTML obsah.',
    'Advanced' => 'Rozšírené',
    'Allows the user to manage custom pages.' => 'Umožňuje používateľovi spravovať vlastné stránky.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Umožňuje pridať stránky (markdown, iframe alebo odkazy) do navigácie priestoru.',
    'Allows you to add content in MarkDown syntax.' => 'Umožňuje pridať obsah v syntaxi MarkDown.',
    'Alternate text' => 'Alternatíva textu',
    'Always make a backup of your view files outside of your production environment!' => 'Vždy urobiť zálohu súborov zobrazenia mimo produkčného prostredia!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Prázdny povolený výber šablóny povolí všetky šablóny kontajnera pre tento kontajner.',
    'Back' => 'Späť',
    'Back to dashboard' => 'Späť na nástenku',
    'Back to overview' => 'Späť na prehľad',
    'Back to space' => 'Späť do priestoru',
    'Can manage custom pages' => 'Môže spravovať vlastné stránky',
    'Cannot delete!' => 'Nedá sa odstrániť!',
    'Category' => 'Kategória',
    'Configuration' => 'Konfigurácia',
    'Content' => 'Obsah',
    'Create' => 'Vytvoriť',
    'Css Class' => 'Css Trieda',
    'Custom Pages' => 'Vlastné Stránky',
    'Custom pages' => 'Vlastné stránky',
    'Dashboard' => 'Nástenka',
    'Default' => 'Východzie',
    'Default Content' => 'Predvolený Obsah',
    'Delete' => 'Odstrániť',
    'Deleted.' => 'Odstránené.',
    'Edit' => 'Upraviť',
    'Edit Page' => 'Zmeniť Stránku',
    'Empty' => 'Prázdny',
    'Empty content elements cannot be deleted!' => 'Prázdne prvky obsahu nie je možné odstrániť!',
    'File' => 'Súbor',
    'Footer menu' => 'Menu Pätičky',
    'General' => 'Všeobecné',
    'Global Page' => 'Globálna stránka',
    'Global Widget' => 'Globálny Widget',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Ikona',
    'Iframe' => 'Iframe',
    'Insert' => 'Vložiť',
    'Invalid request data!' => 'Neplatné požadované údaje!',
    'Invalid template selection!' => 'Neplatný výber šablóny!',
    'Invalid type selection' => 'Neplatný výber typu',
    'Invalid view file selection!' => 'Neplatné zobrazenie výberu súboru!',
    'Link' => 'Odkaz',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Nastavenia ponuky',
    'Navigation' => 'Navigácia',
    'On this page you can configure general settings of your custom pages.' => 'Na tejto stránke môžete nakonfigurovať všeobecné nastavenia vlastných stránok.',
    'Overview' => 'Prehľad',
    'PHP' => 'PHP',
    'Page' => 'Stránka',
    'Page Content' => 'Obsah Stránky',
    'Pages' => 'Stránky',
    'Panel' => 'Panel',
    'People Buttons' => 'Tlačítka Ľudí',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Vyberte si jeden z nasledujúcich typov obsahu. Typ obsahu definuje, ako je váš obsah vložený na stránku.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Majte na pamäti, že stránky založené na php sú citlivé na bezpečnostné problémy, najmä pri manipulácii so vstupom používateľa. Pre viac informácií si pozrite osvedčené postupy zabezpečenia <a href="{url}">Yii\'s Najlepšie postupy v oblasti bezpečnosti</a>.',
    'Public' => 'Verejné',
    'Reset' => 'Resetovať',
    'Reset the content to default value' => 'Obnovte obsah na predvolenú hodnotu',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Toto nastavenie vyberte len pre viditeľné textové uzly. Zrušte začiarknutie tohto nastavenia v prípade, že sa tento prvok používa napríklad ako hodnota atribútu HTML.',
    'Settings' => 'Nastavenie',
    'Show additional file information (size)' => 'Zobraziť ďalšie informácie o súbore (veľkosť)',
    'Snippet' => 'Úryvok',
    'Snippets' => 'Úryvky',
    'Sort Order' => 'Poradie zoradenia',
    'Source' => 'Zdroj',
    'Space' => 'Priestor',
    'Space Members only' => 'Iba Členovia Priestoru',
    'Space Navigation' => 'Navigácia Priestoru',
    'Space Page' => 'Stránka Priestoru',
    'Space Widget' => 'Widget Priestoru',
    'Spaces' => 'Priestory',
    'Stream' => 'Prúd',
    'Stream options' => 'Voľby Toku',
    'Style' => 'Štýl',
    'Style Class' => 'Trieda Štýlu',
    'Submit' => 'Vystaviť',
    'Target Url' => 'Cieľová URL',
    'Template' => 'Šablóna',
    'Template Layout' => 'Rozloženie Šablóny',
    'Templates' => 'Šablóny',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Šablóny umožňujú definovať kombinovateľné fragmenty stránok s funkciou inline úprav.',
    'This container does not allow any further items!' => 'Tento kontajner neumožňuje žiadne ďalšie položky!',
    'Title' => 'Názov',
    'Top Navigation' => 'Horná Navigácia',
    'Topics' => 'Témy',
    'Type' => 'Typ',
    'Upload image' => 'Nahrať obrázok',
    'Usage' => 'Použiť',
    'User Account Menu (Settings)' => 'Menu Užívateľského účtu (Nastavenia)',
    'Visibility' => 'Viditeľnosť',
    'Will embed the result of a given url as an iframe element.' => 'Vloží výsledok danej adresy URL ako prvok iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Presmeruje požiadavky na danú (relatívnu alebo absolútnu) adresu URL.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'So stránkami založenými na PHP môžete vytvárať vlastné stránky pomocou zobrazovacích súborov vo vašom súborovom systéme. Viac informácií nájdete v konfigurácii modulu.',
    'Without adding to navigation (Direct link)' => 'Bez pridania do navigácie (Priama linka)',
    'Wrap this HTML page with white panel' => 'Obaliť túto HTML stránku bielym panelom',
    'You are not allowed to delete default content!' => 'Nie je dovolené odstrániť predvolený obsah!',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'Container' => '',
    'Content filters' => '',
    'Custom' => '',
    'Enter post content ID' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Start Page' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/sk/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Pridať</strong> položku {templateName}',
    '<strong>Custom</strong> Pages' => '<strong>Vlastné</strong> Stránky',
    '<strong>Edit</strong> snippet' => '<strong>Zmeniť</strong> snippet',
    'Add' => 'Pridať',
    'Add a file icon before the title' => 'Pridajte ikonu súboru pred názov',
    'Additional IFrame Attributes' => 'Ďalšie atribúty IFrame',
    'Adds plain HTML content to your site.' => 'Pridať na vašu stránku obyčajný HTML obsah.',
    'Advanced' => 'Rozšírené',
    'Allows the user to manage custom pages.' => 'Umožňuje používateľovi spravovať vlastné stránky.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Umožňuje pridať stránky (markdown, iframe alebo odkazy) do navigácie priestoru.',
    'Allows you to add content in MarkDown syntax.' => 'Umožňuje pridať obsah v syntaxi MarkDown.',
    'Alternate text' => 'Alternatíva textu',
    'Always make a backup of your view files outside of your production environment!' => 'Vždy urobiť zálohu súborov zobrazenia mimo produkčného prostredia!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Prázdny povolený výber šablóny povolí všetky šablóny kontajnera pre tento kontajner.',
    'Back' => 'Späť',
    'Back to dashboard' => 'Späť na nástenku',
    'Back to overview' => 'Späť na prehľad',
    'Back to space' => 'Späť do priestoru',
    'Can manage custom pages' => 'Môže spravovať vlastné stránky',
    'Cannot delete!' => 'Nedá sa odstrániť!',
    'Category' => 'Kategória',
    'Configuration' => 'Konfigurácia',
    'Content' => 'Obsah',
    'Create' => 'Vytvoriť',
    'Css Class' => 'Css Trieda',
    'Custom Pages' => 'Vlastné Stránky',
    'Custom pages' => 'Vlastné stránky',
    'Dashboard' => 'Nástenka',
    'Default' => 'Východzie',
    'Default Content' => 'Predvolený Obsah',
    'Delete' => 'Odstrániť',
    'Deleted.' => 'Odstránené.',
    'Edit' => 'Upraviť',
    'Edit Page' => 'Zmeniť Stránku',
    'Empty' => 'Prázdny',
    'Empty content elements cannot be deleted!' => 'Prázdne prvky obsahu nie je možné odstrániť!',
    'File' => 'Súbor',
    'Footer menu' => 'Menu Pätičky',
    'General' => 'Všeobecné',
    'Global Page' => 'Globálna stránka',
    'Global Widget' => 'Globálny Widget',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Ikona',
    'Iframe' => 'Iframe',
    'Insert' => 'Vložiť',
    'Invalid request data!' => 'Neplatné požadované údaje!',
    'Invalid template selection!' => 'Neplatný výber šablóny!',
    'Invalid type selection' => 'Neplatný výber typu',
    'Invalid view file selection!' => 'Neplatné zobrazenie výberu súboru!',
    'Link' => 'Odkaz',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Nastavenia ponuky',
    'Navigation' => 'Navigácia',
    'On this page you can configure general settings of your custom pages.' => 'Na tejto stránke môžete nakonfigurovať všeobecné nastavenia vlastných stránok.',
    'Overview' => 'Prehľad',
    'PHP' => 'PHP',
    'Page' => 'Stránka',
    'Page Content' => 'Obsah Stránky',
    'Pages' => 'Stránky',
    'Panel' => 'Panel',
    'People Buttons' => 'Tlačítka Ľudí',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Vyberte si jeden z nasledujúcich typov obsahu. Typ obsahu definuje, ako je váš obsah vložený na stránku.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Majte na pamäti, že stránky založené na php sú citlivé na bezpečnostné problémy, najmä pri manipulácii so vstupom používateľa. Pre viac informácií si pozrite osvedčené postupy zabezpečenia <a href="{url}">Yii\'s Najlepšie postupy v oblasti bezpečnosti</a>.',
    'Public' => 'Verejné',
    'Reset' => 'Resetovať',
    'Reset the content to default value' => 'Obnovte obsah na predvolenú hodnotu',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Toto nastavenie vyberte len pre viditeľné textové uzly. Zrušte začiarknutie tohto nastavenia v prípade, že sa tento prvok používa napríklad ako hodnota atribútu HTML.',
    'Settings' => 'Nastavenie',
    'Show additional file information (size)' => 'Zobraziť ďalšie informácie o súbore (veľkosť)',
    'Snippet' => 'Úryvok',
    'Snippets' => 'Úryvky',
    'Sort Order' => 'Poradie zoradenia',
    'Source' => 'Zdroj',
    'Space' => 'Priestor',
    'Space Members only' => 'Iba Členovia Priestoru',
    'Space Navigation' => 'Navigácia Priestoru',
    'Space Page' => 'Stránka Priestoru',
    'Space Widget' => 'Widget Priestoru',
    'Spaces' => 'Priestory',
    'Stream' => 'Prúd',
    'Stream options' => 'Voľby Toku',
    'Style' => 'Štýl',
    'Style Class' => 'Trieda Štýlu',
    'Submit' => 'Vystaviť',
    'Target Url' => 'Cieľová URL',
    'Template' => 'Šablóna',
    'Template Layout' => 'Rozloženie Šablóny',
    'Templates' => 'Šablóny',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Šablóny umožňujú definovať kombinovateľné fragmenty stránok s funkciou inline úprav.',
    'This container does not allow any further items!' => 'Tento kontajner neumožňuje žiadne ďalšie položky!',
    'Title' => 'Názov',
    'Top Navigation' => 'Horná Navigácia',
    'Topics' => 'Témy',
    'Type' => 'Typ',
    'Upload image' => 'Nahrať obrázok',
    'Usage' => 'Použiť',
    'User Account Menu (Settings)' => 'Menu Užívateľského účtu (Nastavenia)',
    'Visibility' => 'Viditeľnosť',
    'Will embed the result of a given url as an iframe element.' => 'Vloží výsledok danej adresy URL ako prvok iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Presmeruje požiadavky na danú (relatívnu alebo absolútnu) adresu URL.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'So stránkami založenými na PHP môžete vytvárať vlastné stránky pomocou zobrazovacích súborov vo vašom súborovom systéme. Viac informácií nájdete v konfigurácii modulu.',
    'Without adding to navigation (Direct link)' => 'Bez pridania do navigácie (Priama linka)',
    'Wrap this HTML page with white panel' => 'Obaliť túto HTML stránku bielym panelom',
    'You are not allowed to delete default content!' => 'Nie je dovolené odstrániť predvolený obsah!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Container' => '',
    'Content filters' => '',
    'Custom' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Enter post content ID' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space selection' => '',
    'Start Page' => '',
];
